@@ -1,16 +1,23 @@
 from sys import stdout
 
 
-def progress_bar(progress: float, bar_length: int = 10, message: str = "spotPython tuning:", y=None) -> None:
+def progress_bar(
+    progress: float, bar_length: int = 10, message: str = "spotPython tuning:", y=None, filename=None
+) -> None:
     """
     Displays or updates a console progress bar.
 
     Args:
-        progress (float): a float between 0 and 1. Any int will be converted to a float.
+        progress (float):
+            a float between 0 and 1. Any int will be converted to a float.
             A value under 0 represents a halt.
             A value at 1 or bigger represents 100%.
-        bar_length (int): length of the progress bar
-        message (str): message text to display
+        bar_length (int):
+            length of the progress bar
+        message (str):
+            message text to display
+        filename (str):
+            If not None, write the progress bar to filename.
     """
     status = ""
     if y is not None:
@@ -25,3 +32,6 @@ def progress_bar(progress: float, bar_length: int = 10, message: str = "spotPyth
     text = f"{message} [{'#' * block + '-' * (bar_length - block)}] {progress * 100:.2f}% {status}\r\n"
     stdout.write(text)
     stdout.flush()
+    if filename is not None:
+        with open(filename, "a") as file:
+            file.write(text)
